# Debuginfo packages are disabled to prevent rpmbuild from generating an empty
# debuginfo package for the empty main package.
%global debug_package %{nil}

%bcond_without mingw

Name:           cereal
Version:        1.3.2
Release:        %mkrel 1
Summary:        A header-only C++11 serialization library
Group:          Development/C
# include/cereal/details/polymorphic_impl.hpp is BSL-1.0
# include/cereal/external/base64.hpp is Zlib
# include/cereal/external/rapidjson/ is MIT
# include/cereal/external/rapidxml/license.txt is MIT OR BSL-1.0
License:        BSD-3-Clause AND BSL-1.0 AND Zlib AND MIT AND (MIT OR BSL-1.0)
Url:            https://uscilab.github.io/cereal
Source0:        https://github.com/USCiLab/cereal/archive/v%{version}/%{name}-%{version}.tar.gz

BuildRequires:  cmake
BuildRequires:  boost-devel

%if %{with mingw}
BuildRequires:  mingw32-filesystem
BuildRequires:  mingw32-gcc-c++
BuildRequires:  mingw32-boost

BuildRequires:  mingw64-filesystem
BuildRequires:  mingw64-gcc-c++
BuildRequires:  mingw64-boost
%endif

%description
cereal is a header-only C++11 serialization library. cereal takes arbitrary
data types and reversibly turns them into different representations, such as
compact binary encodings, XML, or JSON. cereal was designed to be fast,
light-weight, and easy to extend - it has no external dependencies and can be
easily bundled with other code or used standalone.

%package devel
Summary:        Development headers and libraries for %{name}
Group:          Development/C
Provides:       %{name}-static = %{version}-%{release}

%description devel
cereal is a header-only C++11 serialization library. cereal takes arbitrary
data types and reversibly turns them into different representations, such as
compact binary encodings, XML, or JSON. cereal was designed to be fast,
light-weight, and easy to extend - it has no external dependencies and can be
easily bundled with other code or used standalone.

This package contains development headers and libraries for the cereal library.


%if %{with mingw}
%package -n mingw32-%{name}
Summary:       MinGW Windows %{name} library

%description -n mingw32-%{name}
MinGW Windows %{name} library.

%package -n mingw64-%{name}
Summary:       MinGW Windows %{name} library

%description -n mingw64-%{name}
MinGW Windows %{name} library.
%endif

%prep
%autosetup

%build
%cmake -DSKIP_PORTABILITY_TEST=ON \
       -DWITH_WERROR=OFF
%cmake_build

%if %{with mingw}
# MinGW build
%mingw_cmake -DSKIP_PORTABILITY_TEST=ON \
             -DBUILD_SANDBOX=OFF \
             -DWITH_WERROR=OFF
%mingw_make_build
%endif

%install
%cmake_install

%if %{with mingw}
%mingw_make_install
%mingw_debug_install_post
%endif

%check
# https://github.com/USCiLab/cereal/issues/744
%ifarch ppc64le
%global testargs --exclude-regex '\(test_complex\|test_pod\)'
%endif
%ctest --output-on-failure %{?testargs}

%files devel
%doc README.md
%license LICENSE
%{_includedir}/%{name}/
%{_libdir}/cmake/%{name}/

%if %{with mingw}
%files -n mingw32-%{name}
%doc README.md
%license LICENSE
%{mingw32_includedir}/%{name}/
%{mingw32_libdir}/cmake/%{name}/

%files -n mingw64-%{name}
%doc README.md
%license LICENSE
%{mingw64_includedir}/%{name}/
%{mingw64_libdir}/cmake/%{name}/
%endif


%changelog
* Tue Jun 03 2025 daviddavid <daviddavid> 1.3.2-1.mga10
+ Revision: 2188005
- initial package cereal

